@@ -1,18 +1,19 @@
+# frozen_string_literal: true
+
 require_relative "helper"
 
 class TestDistributedRemoteServerControlCommands < Minitest::Test
-
   include Helper::Distributed
 
   def test_info
     keys = [
-     "redis_version",
-     "uptime_in_seconds",
-     "uptime_in_days",
-     "connected_clients",
-     "used_memory",
-     "total_connections_received",
-     "total_commands_processed",
+      "redis_version",
+      "uptime_in_seconds",
+      "uptime_in_days",
+      "connected_clients",
+      "used_memory",
+      "total_connections_received",
+      "total_commands_processed"
     ]
 
     infos = r.info
@@ -27,22 +28,22 @@ class TestDistributedRemoteServerControlCommands < Minitest::Test
 
   def test_info_commandstats
     target_version "2.5.7" do
-      r.nodes.each { |n| n.config(:resetstat) }
-      r.ping # Executed on every node
+      r.nodes.each do |n|
+        n.config(:resetstat)
+        n.config(:get, :port)
+      end
 
       r.info(:commandstats).each do |info|
-        assert_equal "1", info["ping"]["calls"]
+        assert_equal '2', info['config']['calls'] # CONFIG RESETSTAT + CONFIG GET = twice
       end
     end
   end
 
   def test_monitor
-    begin
-      r.monitor
-    rescue Exception => ex
-    ensure
-      assert ex.kind_of?(NotImplementedError)
-    end
+    r.monitor
+  rescue Exception => ex
+  ensure
+    assert ex.is_a?(NotImplementedError)
   end
 
   def test_echo
@@ -57,7 +58,7 @@ class TestDistributedRemoteServerControlCommands < Minitest::Test
         redis_usec = rv[0] * 1_000_000 + rv[1]
         ruby_usec = Integer(Time.now.to_f * 1_000_000)
 
-        assert 500_000 > (ruby_usec - redis_usec).abs
+        assert((ruby_usec - redis_usec).abs < 500_000)
       end
     end
   end
