@@ -1,9 +1,7 @@
+# frozen_string_literal: true
+
 module Lint
-
   module SortedSets
-
-    Infinity = 1.0/0.0
-
     def test_zadd
       assert_equal 0, r.zcard("foo")
       assert_equal true, r.zadd("foo", 1, "s1")
@@ -14,38 +12,38 @@ module Lint
       target_version "3.0.2" do
         # XX option
         assert_equal 0, r.zcard("foo")
-        assert_equal false, r.zadd("foo", 1, "s1", :xx => true)
+        assert_equal false, r.zadd("foo", 1, "s1", xx: true)
         r.zadd("foo", 1, "s1")
-        assert_equal false, r.zadd("foo", 2, "s1", :xx => true)
+        assert_equal false, r.zadd("foo", 2, "s1", xx: true)
         assert_equal 2, r.zscore("foo", "s1")
         r.del "foo"
 
         # NX option
         assert_equal 0, r.zcard("foo")
-        assert_equal true, r.zadd("foo", 1, "s1", :nx => true)
-        assert_equal false, r.zadd("foo", 2, "s1", :nx => true)
+        assert_equal true, r.zadd("foo", 1, "s1", nx: true)
+        assert_equal false, r.zadd("foo", 2, "s1", nx: true)
         assert_equal 1, r.zscore("foo", "s1")
         assert_equal 1, r.zcard("foo")
         r.del "foo"
 
         # CH option
         assert_equal 0, r.zcard("foo")
-        assert_equal true, r.zadd("foo", 1, "s1", :ch => true)
-        assert_equal false, r.zadd("foo", 1, "s1", :ch => true)
-        assert_equal true, r.zadd("foo", 2, "s1", :ch => true)
+        assert_equal true, r.zadd("foo", 1, "s1", ch: true)
+        assert_equal false, r.zadd("foo", 1, "s1", ch: true)
+        assert_equal true, r.zadd("foo", 2, "s1", ch: true)
         assert_equal 1, r.zcard("foo")
         r.del "foo"
 
         # INCR option
-        assert_equal 1.0, r.zadd("foo", 1, "s1", :incr => true)
-        assert_equal 11.0, r.zadd("foo", 10, "s1", :incr => true)
-        assert_equal(-Infinity, r.zadd("bar", "-inf", "s1", :incr => true))
-        assert_equal(+Infinity, r.zadd("bar", "+inf", "s2", :incr => true))
+        assert_equal 1.0, r.zadd("foo", 1, "s1", incr: true)
+        assert_equal 11.0, r.zadd("foo", 10, "s1", incr: true)
+        assert_equal(-Float::INFINITY, r.zadd("bar", "-inf", "s1", incr: true))
+        assert_equal(+Float::INFINITY, r.zadd("bar", "+inf", "s2", incr: true))
         r.del 'foo'
         r.del 'bar'
 
         # Incompatible options combination
-        assert_raises(Redis::CommandError) { r.zadd("foo", 1, "s1", :xx => true, :nx => true) }
+        assert_raises(Redis::CommandError) { r.zadd("foo", 1, "s1", xx: true, nx: true) }
       end
     end
 
@@ -73,9 +71,9 @@ module Lint
       target_version "3.0.2" do
         # XX option
         assert_equal 0, r.zcard("foo")
-        assert_equal 0, r.zadd("foo", [1, "s1", 2, "s2"], :xx => true)
+        assert_equal 0, r.zadd("foo", [1, "s1", 2, "s2"], xx: true)
         r.zadd("foo", [1, "s1", 2, "s2"])
-        assert_equal 0, r.zadd("foo", [2, "s1", 3, "s2", 4, "s3"], :xx => true)
+        assert_equal 0, r.zadd("foo", [2, "s1", 3, "s2", 4, "s3"], xx: true)
         assert_equal 2, r.zscore("foo", "s1")
         assert_equal 3, r.zscore("foo", "s2")
         assert_nil r.zscore("foo", "s3")
@@ -84,8 +82,8 @@ module Lint
 
         # NX option
         assert_equal 0, r.zcard("foo")
-        assert_equal 2, r.zadd("foo", [1, "s1", 2, "s2"], :nx => true)
-        assert_equal 1, r.zadd("foo", [2, "s1", 3, "s2", 4, "s3"], :nx => true)
+        assert_equal 2, r.zadd("foo", [1, "s1", 2, "s2"], nx: true)
+        assert_equal 1, r.zadd("foo", [2, "s1", 3, "s2", 4, "s3"], nx: true)
         assert_equal 1, r.zscore("foo", "s1")
         assert_equal 2, r.zscore("foo", "s2")
         assert_equal 4, r.zscore("foo", "s3")
@@ -94,22 +92,22 @@ module Lint
 
         # CH option
         assert_equal 0, r.zcard("foo")
-        assert_equal 2, r.zadd("foo", [1, "s1", 2, "s2"], :ch => true)
-        assert_equal 2, r.zadd("foo", [1, "s1", 3, "s2", 4, "s3"], :ch => true)
+        assert_equal 2, r.zadd("foo", [1, "s1", 2, "s2"], ch: true)
+        assert_equal 2, r.zadd("foo", [1, "s1", 3, "s2", 4, "s3"], ch: true)
         assert_equal 3, r.zcard("foo")
         r.del "foo"
 
         # INCR option
-        assert_equal 1.0, r.zadd("foo", [1, "s1"], :incr => true)
-        assert_equal 11.0, r.zadd("foo", [10, "s1"], :incr => true)
-        assert_equal(-Infinity, r.zadd("bar", ["-inf", "s1"], :incr => true))
-        assert_equal(+Infinity, r.zadd("bar", ["+inf", "s2"], :incr => true))
-        assert_raises(Redis::CommandError) { r.zadd("foo", [1, "s1", 2, "s2"], :incr => true) }
+        assert_equal 1.0, r.zadd("foo", [1, "s1"], incr: true)
+        assert_equal 11.0, r.zadd("foo", [10, "s1"], incr: true)
+        assert_equal(-Float::INFINITY, r.zadd("bar", ["-inf", "s1"], incr: true))
+        assert_equal(+Float::INFINITY, r.zadd("bar", ["+inf", "s2"], incr: true))
+        assert_raises(Redis::CommandError) { r.zadd("foo", [1, "s1", 2, "s2"], incr: true) }
         r.del 'foo'
         r.del 'bar'
 
         # Incompatible options combination
-        assert_raises(Redis::CommandError) { r.zadd("foo", [1, "s1"], :xx => true, :nx => true) }
+        assert_raises(Redis::CommandError) { r.zadd("foo", [1, "s1"], xx: true, nx: true) }
       end
     end
 
@@ -131,7 +129,7 @@ module Lint
 
         assert_equal 3, r.zcard("foo")
         assert_equal 1, r.zrem("foo", ["s1", "aaa"])
-        assert_equal 0, r.zrem("foo", ["bbb", "ccc" "ddd"])
+        assert_equal 0, r.zrem("foo", ["bbb", "ccc", "ddd"])
         assert_equal 1, r.zrem("foo", ["eee", "s3"])
         assert_equal 1, r.zcard("foo")
       end
@@ -145,10 +143,10 @@ module Lint
       assert_equal 11.0, rv
 
       rv = r.zincrby "bar", "-inf", "s1"
-      assert_equal(-Infinity, rv)
+      assert_equal(-Float::INFINITY, rv)
 
       rv = r.zincrby "bar", "+inf", "s2"
-      assert_equal(+Infinity, rv)
+      assert_equal(+Float::INFINITY, rv)
     end
 
     def test_zrank
@@ -173,13 +171,13 @@ module Lint
       r.zadd "foo", 3, "s3"
 
       assert_equal ["s1", "s2"], r.zrange("foo", 0, 1)
-      assert_equal [["s1", 1.0], ["s2", 2.0]], r.zrange("foo", 0, 1, :with_scores => true)
-      assert_equal [["s1", 1.0], ["s2", 2.0]], r.zrange("foo", 0, 1, :withscores => true)
+      assert_equal [["s1", 1.0], ["s2", 2.0]], r.zrange("foo", 0, 1, with_scores: true)
+      assert_equal [["s1", 1.0], ["s2", 2.0]], r.zrange("foo", 0, 1, withscores: true)
 
       r.zadd "bar", "-inf", "s1"
       r.zadd "bar", "+inf", "s2"
-      assert_equal [["s1", -Infinity], ["s2", +Infinity]], r.zrange("bar", 0, 1, :with_scores => true)
-      assert_equal [["s1", -Infinity], ["s2", +Infinity]], r.zrange("bar", 0, 1, :withscores => true)
+      assert_equal [["s1", -Float::INFINITY], ["s2", +Float::INFINITY]], r.zrange("bar", 0, 1, with_scores: true)
+      assert_equal [["s1", -Float::INFINITY], ["s2", +Float::INFINITY]], r.zrange("bar", 0, 1, withscores: true)
     end
 
     def test_zrevrange
@@ -188,13 +186,13 @@ module Lint
       r.zadd "foo", 3, "s3"
 
       assert_equal ["s3", "s2"], r.zrevrange("foo", 0, 1)
-      assert_equal [["s3", 3.0], ["s2", 2.0]], r.zrevrange("foo", 0, 1, :with_scores => true)
-      assert_equal [["s3", 3.0], ["s2", 2.0]], r.zrevrange("foo", 0, 1, :withscores => true)
+      assert_equal [["s3", 3.0], ["s2", 2.0]], r.zrevrange("foo", 0, 1, with_scores: true)
+      assert_equal [["s3", 3.0], ["s2", 2.0]], r.zrevrange("foo", 0, 1, withscores: true)
 
       r.zadd "bar", "-inf", "s1"
       r.zadd "bar", "+inf", "s2"
-      assert_equal [["s2", +Infinity], ["s1", -Infinity]], r.zrevrange("bar", 0, 1, :with_scores => true)
-      assert_equal [["s2", +Infinity], ["s1", -Infinity]], r.zrevrange("bar", 0, 1, :withscores => true)
+      assert_equal [["s2", +Float::INFINITY], ["s1", -Float::INFINITY]], r.zrevrange("bar", 0, 1, with_scores: true)
+      assert_equal [["s2", +Float::INFINITY], ["s1", -Float::INFINITY]], r.zrevrange("bar", 0, 1, withscores: true)
     end
 
     def test_zrangebyscore
@@ -219,9 +217,9 @@ module Lint
       r.zadd "foo", 3, "s3"
       r.zadd "foo", 4, "s4"
 
-      assert_equal ["s2"], r.zrangebyscore("foo", 2, 4, :limit => [0, 1])
-      assert_equal ["s3"], r.zrangebyscore("foo", 2, 4, :limit => [1, 1])
-      assert_equal ["s3", "s4"], r.zrangebyscore("foo", 2, 4, :limit => [1, 2])
+      assert_equal ["s2"], r.zrangebyscore("foo", 2, 4, limit: [0, 1])
+      assert_equal ["s3"], r.zrangebyscore("foo", 2, 4, limit: [1, 1])
+      assert_equal ["s3", "s4"], r.zrangebyscore("foo", 2, 4, limit: [1, 2])
     end
 
     def test_zrevrangebyscore_with_limit
@@ -230,9 +228,9 @@ module Lint
       r.zadd "foo", 3, "s3"
       r.zadd "foo", 4, "s4"
 
-      assert_equal ["s4"], r.zrevrangebyscore("foo", 4, 2, :limit => [0, 1])
-      assert_equal ["s3"], r.zrevrangebyscore("foo", 4, 2, :limit => [1, 1])
-      assert_equal ["s3", "s2"], r.zrevrangebyscore("foo", 4, 2, :limit => [1, 2])
+      assert_equal ["s4"], r.zrevrangebyscore("foo", 4, 2, limit: [0, 1])
+      assert_equal ["s3"], r.zrevrangebyscore("foo", 4, 2, limit: [1, 1])
+      assert_equal ["s3", "s2"], r.zrevrangebyscore("foo", 4, 2, limit: [1, 2])
     end
 
     def test_zrangebyscore_with_withscores
@@ -241,17 +239,17 @@ module Lint
       r.zadd "foo", 3, "s3"
       r.zadd "foo", 4, "s4"
 
-      assert_equal [["s2", 2.0]], r.zrangebyscore("foo", 2, 4, :limit => [0, 1], :with_scores => true)
-      assert_equal [["s3", 3.0]], r.zrangebyscore("foo", 2, 4, :limit => [1, 1], :with_scores => true)
-      assert_equal [["s2", 2.0]], r.zrangebyscore("foo", 2, 4, :limit => [0, 1], :withscores => true)
-      assert_equal [["s3", 3.0]], r.zrangebyscore("foo", 2, 4, :limit => [1, 1], :withscores => true)
+      assert_equal [["s2", 2.0]], r.zrangebyscore("foo", 2, 4, limit: [0, 1], with_scores: true)
+      assert_equal [["s3", 3.0]], r.zrangebyscore("foo", 2, 4, limit: [1, 1], with_scores: true)
+      assert_equal [["s2", 2.0]], r.zrangebyscore("foo", 2, 4, limit: [0, 1], withscores: true)
+      assert_equal [["s3", 3.0]], r.zrangebyscore("foo", 2, 4, limit: [1, 1], withscores: true)
 
       r.zadd "bar", "-inf", "s1"
       r.zadd "bar", "+inf", "s2"
-      assert_equal [["s1", -Infinity]], r.zrangebyscore("bar", -Infinity, +Infinity, :limit => [0, 1], :with_scores => true)
-      assert_equal [["s2", +Infinity]], r.zrangebyscore("bar", -Infinity, +Infinity, :limit => [1, 1], :with_scores => true)
-      assert_equal [["s1", -Infinity]], r.zrangebyscore("bar", -Infinity, +Infinity, :limit => [0, 1], :withscores => true)
-      assert_equal [["s2", +Infinity]], r.zrangebyscore("bar", -Infinity, +Infinity, :limit => [1, 1], :withscores => true)
+      assert_equal [["s1", -Float::INFINITY]], r.zrangebyscore("bar", -Float::INFINITY, +Float::INFINITY, limit: [0, 1], with_scores: true)
+      assert_equal [["s2", +Float::INFINITY]], r.zrangebyscore("bar", -Float::INFINITY, +Float::INFINITY, limit: [1, 1], with_scores: true)
+      assert_equal [["s1", -Float::INFINITY]], r.zrangebyscore("bar", -Float::INFINITY, +Float::INFINITY, limit: [0, 1], withscores: true)
+      assert_equal [["s2", +Float::INFINITY]], r.zrangebyscore("bar", -Float::INFINITY, +Float::INFINITY, limit: [1, 1], withscores: true)
     end
 
     def test_zrevrangebyscore_with_withscores
@@ -260,17 +258,17 @@ module Lint
       r.zadd "foo", 3, "s3"
       r.zadd "foo", 4, "s4"
 
-      assert_equal [["s4", 4.0]], r.zrevrangebyscore("foo", 4, 2, :limit => [0, 1], :with_scores => true)
-      assert_equal [["s3", 3.0]], r.zrevrangebyscore("foo", 4, 2, :limit => [1, 1], :with_scores => true)
-      assert_equal [["s4", 4.0]], r.zrevrangebyscore("foo", 4, 2, :limit => [0, 1], :withscores => true)
-      assert_equal [["s3", 3.0]], r.zrevrangebyscore("foo", 4, 2, :limit => [1, 1], :withscores => true)
+      assert_equal [["s4", 4.0]], r.zrevrangebyscore("foo", 4, 2, limit: [0, 1], with_scores: true)
+      assert_equal [["s3", 3.0]], r.zrevrangebyscore("foo", 4, 2, limit: [1, 1], with_scores: true)
+      assert_equal [["s4", 4.0]], r.zrevrangebyscore("foo", 4, 2, limit: [0, 1], withscores: true)
+      assert_equal [["s3", 3.0]], r.zrevrangebyscore("foo", 4, 2, limit: [1, 1], withscores: true)
 
       r.zadd "bar", "-inf", "s1"
       r.zadd "bar", "+inf", "s2"
-      assert_equal [["s2", +Infinity]], r.zrevrangebyscore("bar", +Infinity, -Infinity, :limit => [0, 1], :with_scores => true)
-      assert_equal [["s1", -Infinity]], r.zrevrangebyscore("bar", +Infinity, -Infinity, :limit => [1, 1], :with_scores => true)
-      assert_equal [["s2", +Infinity]], r.zrevrangebyscore("bar", +Infinity, -Infinity, :limit => [0, 1], :withscores => true)
-      assert_equal [["s1", -Infinity]], r.zrevrangebyscore("bar", +Infinity, -Infinity, :limit => [1, 1], :withscores => true)
+      assert_equal [["s2", +Float::INFINITY]], r.zrevrangebyscore("bar", +Float::INFINITY, -Float::INFINITY, limit: [0, 1], with_scores: true)
+      assert_equal [["s1", -Float::INFINITY]], r.zrevrangebyscore("bar", +Float::INFINITY, -Float::INFINITY, limit: [1, 1], with_scores: true)
+      assert_equal [["s2", +Float::INFINITY]], r.zrevrangebyscore("bar", +Float::INFINITY, -Float::INFINITY, limit: [0, 1], withscores: true)
+      assert_equal [["s1", -Float::INFINITY]], r.zrevrangebyscore("bar", +Float::INFINITY, -Float::INFINITY, limit: [1, 1], withscores: true)
     end
 
     def test_zcard
@@ -291,8 +289,8 @@ module Lint
 
       r.zadd "bar", "-inf", "s1"
       r.zadd "bar", "+inf", "s2"
-      assert_equal(-Infinity, r.zscore("bar", "s1"))
-      assert_equal(+Infinity, r.zscore("bar", "s2"))
+      assert_equal(-Float::INFINITY, r.zscore("bar", "s1"))
+      assert_equal(+Float::INFINITY, r.zscore("bar", "s2"))
     end
 
     def test_zremrangebyrank
